Learn R Programming

mutoss (version 0.1-8)

ABH_pi0_est: Lowest Slope Line (LSL) method of Hochberg and Benjamini for estimating pi0

Description

The Lowest Slope Line (LSL) method of Hochberg and Benjamini for estimating pi0 is applied to pValues. This method for estimating pi0 is motivated by the graphical approach proposed by Schweder and Spjotvoll (1982), as developed and presented in Hochberg and Benjamini (1990).

Usage

ABH_pi0_est(pValues)

Arguments

pValues
The raw p-values for the marginal test problems

Value

  • pi0.ABHThe estimated proportion of true null hypotheses.

References

Hochberg, Y. and Benjamini, Y. (1990). More powerful procedures for multiple significance testing. Statistics in Medicine 9, 811-818.

Schweder, T. and Spjotvoll, E. (1982). Plots of P-values to evaluate many tests simultaneously. Biometrika 69, 3, 493-502.

Examples

Run this code
my.pvals <- c(runif(50), runif(50, 0, 0.01))
result <- ABH_pi0_est(my.pvals)

Run the code above in your browser using DataLab