Learn R Programming

mutoss (version 0.1-9)

SidakSD: Sidak-like (1987) step-down procedure

Description

The Sidak-like (1987) step-down procedure is applied to pValues The Sidak-like step-down procedure is an improvement over the Holm's (1979) step-down procedure. The improvement is analogous to Sidak's correction over the original Bonferroni procedure. This Sidak-like step-down procedure assumes positive orthant dependent test statistics.

Usage

SidakSD(pValues, alpha, silent=FALSE)

Arguments

pValues
The used raw pValues.
alpha
The level at which the FWER shall be controlled.
silent
If true any output on the console will be suppressed.

Value

  • A list containing:
  • adjPValuesa numeric vector containing the adjusted pValues
  • rejecteda logical vector indicating which hypotheses are rejected
  • criticalValuesa numeric vector containing critical values used in the step-up-down test
  • errorControlA Mutoss S4 class of type errorControl, containing the type of error controlled by the function and the level alpha.

References

Hollander, B.S. and Covenhaver, M.D. (1987). An Improved Sequentially Rejective Bonferroni Test Procedure. Biometrics, 43(2):417-423, 1987.

Examples

Run this code
alpha <- 0.05
p <-c(runif(10, min=0, max=0.01), runif(10, min=0.9,max=1))
result <- SidakSD(p, alpha)
result <- SidakSD(p, alpha, silent=TRUE)

Run the code above in your browser using DataLab