Learn R Programming

mutoss (version 0.1-10)

TSBKY_pi0_est: Two-step estimation method of Benjamini, Krieger and Yekutieli for estimating pi0

Description

The two-step estimation method of Benjamini, Krieger and Yekutieli for estimating pi0 is applied to pValues. It consists of the following two steps: Step 1. Use the linear step-up procedure at level alpha' =alpha/(1+alpha). Let r1 be the number of rejected hypotheses. If r1=0 do not reject any hypothesis and stop; if r1=m reject all m hypotheses and stop; otherwise continue. Step 2. Let $\hat{m0} =(m - r1)$ and $\hat{pi0} = \hat{m0} / m$.

Usage

TSBKY_pi0_est(pValues, alpha)

Arguments

pValues
The raw p-values for the marginal test problems
alpha
The parameter (to be interpreted as significance level) for the procedure

Value

References

Benjamini, Y., Krieger, A. and Yekutieli, D. (2006). Adaptive linear step-up procedures that control the false discovery rate Biometrika 93, 3, page 495.

Examples

Run this code
result <- TSBKY_pi0_est(my.pvals, 0.1)

Run the code above in your browser using DataLab