Learn R Programming

mutoss (version 0.1-10)

compareMutoss: Functions for comparing outputs of different procedures.

Description

Functions for comparing outputs of different procedures.

Usage

compareMutoss(...) mu.compare.adjusted(comparison.list, identify.check=F) mu.compare.critical(comparison.list, identify.check=F) mu.compare.summary(comparison.list)

Arguments

...
An arbitrary number of Motoss class objects.
comparison.list
The output of the compareMutoss function.
identify.check
Logical parameter specifying if hypotheses should be identified on the output plots.

Value

mu.compare.adjusted
Creates a plot with the adjusted p-values for each procedure.
mu.compare.critical
Creates a plot with the critical values for each procedure and error rate.
mu.compare.summary
Creates a short textual summary for comparing results of different procedures.

Details

These functions are used to compare the results of different multiple comparisons procedures stored as Mutoss class objects. compareMutoss takes as input an arbitrary number of Mutoss objects and arranges them in a simple list objects (non S4). mu.compare.adjuted, mu.compare.critical and mu.compare.summary take the output of the compareMutoss and plots or summerize the results textually or graphically.

Examples

Run this code
## Not run: 
# \dontrun{Creating several Mutoss class objects}
# mu.test.obj.1 <- mutoss.apply(new(Class="Mutoss", 
#                                   pValues=runif(10)), 
#                                   f=bonferroni, 
#                                   label="Bonferroni Correction", 
#                                   alpha=0.05, 
#                                   silent=T)
# mu.test.obj.2 <- mutoss.apply(new(Class="Mutoss", 
#                                   pValues=runif(10)), 
#                                   f=holm, 
#                                   label="Holm's step-down-procedure", 
#                                   alpha=0.05,
#                                   silent=T)
# mu.test.obj.3 <- mutoss.apply(new(Class="Mutoss", 
#                                   pValues=runif(10)), 
#                                   f=aorc, 
#                                   label="Asymtotically optimal rejection curve", 
#                                   alpha=0.05, 
#                                   startIDX_SUD = 1, 
#                                   silent=T)
# \dontrun{Trying to coercing a non-Mutoss object}
# compareMutoss(1)
# \dontrun{ Coercing several objects into a list}
# compare.1<- compareMutoss(mu.test.obj.1, mu.test.obj.2)
# compare.2<- compareMutoss(mu.test.obj.1, mu.test.obj.2, mu.test.obj.3)
# \dontrun{Plotting the adjusted pvalues. Identification available.}
# mu.compare.adjusted(compare.1, T)
# mu.compare.adjusted(compare.2, T)
# \dontrun{Plotting the critical values. Identification available.}
# mu.compare.critical(compare.1, T)
# mu.compare.critical(compare.2, T)
# \dontrun{Showing a textual sumary}
# mu.compare.summary(compare.1)
# mu.compare.summary(compare.2)
# ## End(Not run)

Run the code above in your browser using DataLab