Learn R Programming

mutoss (version 0.1-3)

hochberg: Hochberg (1988) step-up procedure

Description

The Hochberg step-up procedure is based on marginal p-values. It controls the FWER in the strong sense under joint null distributions of the test statistics that satisfy Simes' inequality.

Usage

hochberg(pValues, alpha, silent=FALSE)

Arguments

pValues
The used raw pValues.
alpha
The level at which the FDR shall be controlled.
silent
If true any output on the console will be suppressed.

Value

  • A list containing:
  • adjPValuesA numeric vector containing the adjusted pValues
  • rejectedA logical vector indicating which hypotheses are rejected
  • criticalValuesA numeric vector containing critical values used in the step-up-down test
  • errorControlA Mutoss S4 class of type errorControl, containing the type of error controlled by the function and the level alpha.

Details

The Hochberg procedure is more powerful than Holm's (1979) procedure, but the test statistics need to be independent or have a distribution with multivariate total positivity of order two or a scale mixture thereof for its validity (Sarkar, 1998). Both procedures use the same set of critical values c(i)=alpha/(m-i+1). Whereas Holm's procedure is a step-down version of the Bonferroni test, and Hochberg's is a step-up version of the Bonferroni test. Note that Holm's method is based on the Bonferroni inequality and is valid regardless of the joint distribution of the test statistics.

References

Hochberg, Y. (1988). A sharper Bonferroni procedure for multiple tests of significance. Biometrika, 75:800-802.$n$

Huang, Y. and Hsu, J. (2007). Hochberg's step-up method: cutting corners off Holm's step-down method. Biometrika, 94(4):965-975.

Examples

Run this code
alpha <- 0.05
p <-c(runif(10, min=0, max=0.01), runif(10, min=0.9,max=1))
result <- hochberg(p, alpha)
result <- hochberg(p, alpha, silent=TRUE)

Run the code above in your browser using DataLab