jointCDF.orderedUnif: Joint cumulative distribution function of order statistics of n iid. U(0,1)-distributed random variables
Description
Calculates the joint cumulative distribution function of order statistics
of n iid. U(0,1)-distributed random variables at argument vec.
Because of numerical issues n should not be greater than 100.
Usage
jointCDF.orderedUnif(vec)
Arguments
vec
a numeric vector. The length of the vector also
determines the number of random variables considered.