Learn R Programming

mutoss (version 0.1-10)

mutoss.apply: Applies a function to a Mutoss object.

Description

Applies a function to a Mutoss object.

Usage

mutoss.apply(mutossObj, f, label = deparse(substitute(f)) , recordHistory = TRUE , ...)

Arguments

mutossObj
the Mutoss object the function should be applied to
f
the function that should be applied
label
the label affixed to all slots of the Mutoss object that are changed by the procedure, defaults to the name of parameter f
recordHistory
if true, the calling command is concatenated verbatim to the commandHistory slot
...
additional parameters that are passed to the function

Value

mutossObj
Object of S4 class Mutoss

Details

This functions is intended for applying functions for multiplicity control on Mutoss class objects using the console and not the Mutoss GUI.

Examples

Run this code
  f=bonferroni, label="Bonferroni Correction", alpha=0.05)
## Not run:  TODO: EXAMPLE PROBLEM
# newObjectHolm <- mutoss.apply(new(Class="Mutoss", pValues=runif(10)), 
#   f=holm, label="Holm's step-down-procedure", alpha=0.05, silent=T)
# 
# newObjectAORC <- mutoss.apply(new(Class="Mutoss", pValues=runif(10)), 
#   f=aorc, label="Asymptotically optimal rejection curve", alpha=0.05, startIDX_SUD = 1, silent=T)
# ## End(Not run)

Run the code above in your browser using DataLab