Rdocumentation
powered by
Learn R Programming
mutoss (version 0.1-10)
mutoss.models: Mutoss Models
Description
Fisher-type (2x3) table as model for marginal hypotheses testing problems, Fisher (2x2) table as model for marginal hypotheses testing problems and others...
Arguments
Value