Learn R Programming

mutoss (version 0.1-10)

nparcomp.wrapper: Simultaneous confidence intervals for relative contrast effects...

Description

Simultaneous confidence intervals for relative contrast effects The procedure controls the FWER in the strong sense.

Usage

nparcomp.wrapper(model, data, hypotheses, alpha, alternative, asy.method)

Arguments

model
A two-sided formula specifying a numeric response variable and a factor with more than two levels.
data
A dataframe containing the variables specified the model
hypotheses
Character string defining the type of contrast. It should be one of "Tukey", "Dunnett", "Sequen", "Williams", "Changepoint", "AVE", "McDermott", "Marcus".
alpha
the significance level
alternative
Character string defining the alternative hypothesis, one of "two.sided", "less" or "greater"
asy.method
A character string defining the asymptotic approximation method, one of "logit", for using the logit transformation function, "probit", for using the probit transformation function, "normal", for using the multivariate normal

Value

adjPValues
A numeric vector containing the adjusted pValues
rejected
A logical vector indicating which hypotheses are rejected
confIntervals
A matrix containing the estimates and the lower and upper confidence bound
errorControl
A Mutoss S4 class of type errorControl, containing the type of error controlled by the function.

Details

With this function, it is possible to compute nonparametric simultaneous confidence intervals for relative contrast effects in the unbalanced one way layout. Moreover, it computes adjusted p-values. The simultaneous confidence intervals can be computed using multivariate normal distribution, multivariate t-distribution with a Satterthwaite Approximation of the degree of freedom or using multivariate range preserving transformations with Logit or Probit as transformation function. There is no assumption on the underlying distribution function, only that the data have to be at least ordinal numbers