Learn R Programming

mutoss (version 0.1-9)

pval2locfdr: Strimmer et al.'s fdrtool-based local fdr

Description

The function pval2locfdr takes a vector of p-values and estimates for each case the local fdr.

Usage

pval2locfdr(pValues, cutoff)

Arguments

pValues
pValues to be used.
cutoff
The local fdr cutoff for rejection. Hypotheses with local fdr smaller then cutoff will be rejected.

Value

  • A list containing:
  • locfdrNumeric vector with local FDR values for each case
  • rejectedLogical vector indicating rejection/retention for each hypothesis when a cutoff is supplied.

References

Strimmer, K. (2008). fdrtool: a versatile R package for estimating local and tail area-based false discovery rates. Bioinformatics 24: 1461-1462. Efron B., Tibshirani R., Storey J. D. and Tusher, V. (2001). Empirical Bayes Analysis of a Microarray Experiment. Journal of the American Statistical Association 96(456):1151-1160.

Examples

Run this code
pvals<- runif(1000)^2
pval2locfdr(pvals)
pval2locfdr(pValues=pvals, cutoff=0.4)

Run the code above in your browser using DataLab