rom(pValues, alpha, silent=FALSE)errorControl, containing the type of error controlled by the function and the level alpha.Since the formula for the critical values is recursive, the calculation of adjusted pValues is far from obvious and is not implemented here.
Finner, H. and Roters, M. (2002). Multiple hypotheses testing and expected type I errors. Ann. Statist. 30, 220-238.
result <- rom(r, 0.05)
result <- rom(r, 0.05, silent = TRUE)Run the code above in your browser using DataLab