Learn R Programming

mutoss (version 0.1-9)

twosamp.marginal: Marginal two sample test

Description

The robust version uses the Wilcoxon-Mann-Whitney test, otherwise a two-sample t-test will be performed.

Usage

twosamp.marginal(data, model, robust, alternative, psi0, equalvar)

Arguments

data
the data set
model
the result of a call to twosamp.model(classlabel)
robust
a logical variable indicating whether a two sample t-test or a Wilcoxon-Mann-Whitney test should be used.
alternative
a character string specifying the alternative hypothesis, must be one of two.sided, greater or less
psi0
a numeric that defines the hypothesized null value
equalvar
a logical variable indicating whether to treat the two variances as being equal

Value

  • pValuesA numeric vector containing the unadjusted pValues

Details

A vector of classlabels needs to be provided to distinguish the two groups.

References

Wilcoxon, F. (1945). Individual Comparisons by Ranking Methods. Biometrics Bulletin 1:80-83. Mann, H. and Whitney, D. (1947). On a test of whether one of two random variables is stochastically larger than the other. Annals of Mathematical Statistics 18:50-60 Student (1908). The probable error of a mean. Biometrika, 6(1):1-25.