ErrorControl-class: Class ErrorControl
Description
This class holds the information related to the error rateSlots
type:- a character specifying the error rate. For example FWER, FDR, ...
alpha:- the level at which the error rate shall be controlled
k:- an additional parameter for generalised FWER
q:- an additional parameter for FDX (false discovery exceedance)