Mutoss-class: Class Mutoss
Description
A Mutoss object can store the input for a multiple test procedure and also the output.Slots
data:- Raw data used in model
model:- link function,error family and design
description:- a general description
statistic:- for Z, T or F statistics
hypotheses:- of class ANY
hypNames:- identifiers for the hypotheses tested
criticalValues:- procedure-specific critical values
pValues:- raw p-values
adjPValues:- procedure-specific adjusted p-values
errorControl:- A Mutoss S4 class of type
errorControl rejected:- Logical vector of the output of a procedure at a given error rate
qValues:- Storey's estimates of the supremum of the pFDR
locFDR:- Efron's local fdr estimates
pi0:- Estimate of the proportion of null hypotheses
confIntervals:- Confidence intervals for selected parameters
commandHistory:- commandHistory