MutossMethod-class: Class MutossMethod
Description
A MutossMethod object describes a method that is applicable to Mutoss objects.Slots
label:- A character string that contains the label that will be shown in menus.
errorControl:- One of the following character strings: FWER, FWER.weak, FDR, FDX, gFWER, perComparison.
callFunction:- A character string that contains the name of the Mutoss-compatible function.
output:- A character vector of the possible output of the function.
info:- A character string with info text. Should contain small description, author, reference etc..
assumptions:- A character vector of assumptions for this method.
parameters:- A list of optional description of parameters - see MuToss developer handbook.
list:- For extensions a list where you can put all your miscellaneous stuff.